function [dis] = Hata_calculator_without_diffraction_BJTU(a,b,map,map2,res,Tz,Rz,f,br_height)
%INPUT
% a - starting value [column row]
% b - ending value [column row]
% map - raster database map of height [m]
% map2 - raster database of various clutters
% res - resolution of the raster database [?m,?m]
% Tz - Tx antenna height relative to the ground (track) [m]
% Rz - Rx antenna height relative to the ground (track) [m]
% f - frequenz [MHz]
% br_height - crossing bridge height relative to the ground (track) [m]
%
% OUTPUT
% PL - propagation loss of Hata model [dB]
% dis - distance between Tx and Rx [km]
% 
% Author: Dr. Ke Guan
% Date: 20.07.2016


profile = clutter_bresenham2_BJTU(a,b,map,map2,res,br_height);
idx_ms=length(profile(:,1));
dis = profile(end,4).*1E-3;

ENV=map2(b(2),b(1));

    if ismember(ENV,[0 1 2])     %1 city core zones, 2 city buildings, 
    env = 0;   
    elseif ismember(ENV,[3 4 5 6 7]) %3 loose buildings, 4 industries, 5 sealed surfaces 6 conniferous forest, 7 deciduous forest
    env = 1;   
    else
    env = 2;
    end


 

end

 
 